==> open-xchange-guard_2.10.0.orig.tar.bz2: open-xchange-guard-2.10.0/com.openexchange.guard.user/src/com/openexchange/guard/user/OXUser.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.user;

import java.util.Locale;
import com.openexchange.guard.common.util.LocaleUtil;

/**
 * {@link OXUser} represents a regular OX Appsuite User
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since v2.4.0
 */
public class OXUser {

    private final String  email;
    private final int     id;
    private final int     contextId;
    private final String  language;
    private final String  name;
    private final boolean isGuest;

    /**
     *
     * Initializes a new {@link OXUser}.
     *
     * @param email The user's email
     * @param id The user's ID
     * @param contextId The users' context ID
     * @param name The name of the user
     * @param isGuest True if the user is a OX Appsuite guest, False otherwise
     * @param language The language of the user
     */
    public OXUser(String email, int id, int contextId, String name, boolean isGuest, String language) {
        this.email = email;
        this.id = id;
        this.contextId = contextId;
        this.name = name;
        this.isGuest = isGuest;
        this.language = language;
    }

    /**
     * Gets the email of the user
     *
     * @return The user's email
     */
    public String getEmail() {
        return email;
    }

    /**
     * Gets the context ID of the user
     *
     * @return The context ID of the user
     */
    public int getContextId() {
        return contextId;
    }

    public int getId() {
        return id;
    }

    /**
     * Gets the user's language
     *
     * @return The language of the user
     */
    public String getLanguage() {
        return language;
    }

    /**
     * Gets the user's locale
     *
     * @return The locale
     */
    public Locale getLocale() {
        return LocaleUtil.getLocalFor(language);
    }

    /**
     * Gets the user's name
     *
     * @return The name of the user
     */
    public String getName() {
        return name;
    }

    /**
     * Gets whether or not the user is an OX Appsuite guest
     * @return True if the user is an OX Appsuite guest, false otherwise
     */
    public boolean isGuest() {
        return this.isGuest;
    }
}

==> open-xchange-guard_2.10.1.orig.tar.bz2: open-xchange-guard-2.10.1/com.openexchange.guard.user/src/com/openexchange/guard/user/OXUser.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.user;

import java.util.Locale;
import com.openexchange.guard.common.util.LocaleUtil;

/**
 * {@link OXUser} represents a regular OX Appsuite User
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since v2.4.0
 */
public class OXUser {

    private final String  email;
    private final String  language;
    private final String  name;
    private final boolean isGuest;
    private int     id;
    private int     contextId;

    /**
     *
     * Initializes a new {@link OXUser}.
     *
     * @param email The user's email
     * @param id The user's ID
     * @param contextId The users' context ID
     * @param name The name of the user
     * @param isGuest True if the user is a OX Appsuite guest, False otherwise
     * @param language The language of the user
     */
    public OXUser(String email, int id, int contextId, String name, boolean isGuest, String language) {
        this.email = email;
        this.id = id;
        this.contextId = contextId;
        this.name = name;
        this.isGuest = isGuest;
        this.language = language;
    }

    /**
     * Gets the email of the user
     *
     * @return The user's email
     */
    public String getEmail() {
        return email;
    }

    /**
     * Gets the context ID of the user
     *
     * @return The context ID of the user
     */
    public int getContextId() {
        return contextId;
    }

    public void setContextId(int contextId) {
        this.contextId = contextId;
    }


    public int getId() {
        return id;
    }

    public void setUserId(int userId) {
        this.id = userId;
    }

    /**
     * Gets the user's language
     *
     * @return The language of the user
     */
    public String getLanguage() {
        return language;
    }

    /**
     * Gets the user's locale
     *
     * @return The locale
     */
    public Locale getLocale() {
        return LocaleUtil.getLocalFor(language);
    }

    /**
     * Gets the user's name
     *
     * @return The name of the user
     */
    public String getName() {
        return name;
    }

    /**
     * Gets whether or not the user is an OX Appsuite guest
     * @return True if the user is an OX Appsuite guest, false otherwise
     */
    public boolean isGuest() {
        return this.isGuest;
    }
}
